@@ -8,7 +8,7 @@ BEGIN {
     use Path::Class::Dir ();
 
     __PACKAGE__->config(
-        resource_name  => 'products',
+        resource_name  => 'mango/products',
         form_directory => Path::Class::Dir->new(Mango->share, 'forms', 'products')
     );
 };
